// OpenMath FloatNode interface

package fr.inria.openmath.omapi;

/**
 * Defines accessor/mutators for this kind of Node.
 * <p>Floats may have a prefered base.
 * When they are parsed or printed this may impact the precision loss.
 */
public interface FloatNode {

    /** The hexadecimal is the less error prone base.
     * parse/print/parse/print cycles are done without precision loss.
     */
    public static final int HEXA_DECIMAL = 16;

    /** The decimal base is the more human readable.
     * (at least in some encodings like XML)
     */
    public static final int DECIMAL = 10;

    /**
     * Set the prefered base for a Float object.
     *
     * <p>If this object has been created by a Parser this value has probably
     * been set to match the one found during parse.
     * @exception OMException If the base is not legal throws OME_UNLEGAL_BASE
     */
    public void setPreferedBase(int base) throws OMException ;

    public int getPreferedBase() ;

    public void setValue(double value) ;

    public double getValue() ;

}
