// OpenMath base ParserErrorHandler class.

package fr.inria.openmath.omapi;

/**
 * Default base class for ParserErrorHandler.
 *
 * <p>This class implements the default behaviour for ParserErrorHandler.</p>
 *
 * <p>Application writers can extend this class when they need to
 * implement only part of an interface; parser writers can
 * instantiate this class to provide default handlers when the
 * application has not supplied its own.</p>
 *
 * <p>Note that the use of this class is optional.</p>
 *
 * @see fr.inria.openmath.omapi.ParserErrorHandler
 */
public class ParserErrorAdapter
        implements fr.inria.openmath.omapi.ParserErrorHandler {

    /**
     * Receives notification of a warning.
     *
     * <p>By default, do nothing.  Application writers may override this
     * method in a subclass.</p>
     *
     * @param exception The trouble-shouting information encapsulated in a
     *                  OpenMath exception.
     * @exception fr.inria.openmath.omapi.OMException Any OpenMath exception.
     * @see fr.inria.openmath.omapi.OMException
     */
    public void warning(OMException exception) throws OMException {} // no op

    /**
     * Receives notification of a recoverable error.
     *
     * <p>By default, do nothing.  Application writers may override this
     * method in a subclass.</p>
     *
     * @param exception The trouble-shouting information encapsulated in a
     *                  OpenMath exception.
     * @exception fr.inria.openmath.omapi.OMException Any OpenMath exception.
     * @see fr.inria.openmath.omapi.OMException
     */
    public void error(OMException exception) throws OMException {} // no op

    /**
     * Receives notification of a non-recoverable error.
     *
     * <p>Throws the fatal exception.</p>
     *
     * @param exception The trouble-shouting information encapsulated in a
     *                  OpenMath exception.
     * @exception fr.inria.openmath.omapi.OMException Any OpenMath exception.
     * @see fr.inria.openmath.omapi.OMException
     */
    public void fatalError(OMException exception) throws OMException {
        throw exception;
    }

}
