
# Rule for normal .java -> .class compilation
%.class: %.java
	@Base=`echo $< | cut -d'.' -f1`; \
          (echo "  -------------------"; \
          echo "  make $$Base (javac $<)") 1>&2;
	javac -deprecation $<

# build in all subdirs
buildSubDirs:
	@if [ ! -z "$(SUBDIRS)" ] ; \
        then \
	  echo "Building all .class in subdirs ..."; \
          for Dir in ""$(SUBDIRS) ; do \
            echo "------------------- in $$Dir"; \
            cd $$Dir >/dev/null; \
            $(MAKE) build >/dev/null; \
            cd ..; \
            echo "------------------- (done)"; \
          done; \
          echo "done"; \
        fi

buildlocal bl:
	@echo "Building all .class ..."
	@for File in *.java ; do \
           Base=`echo $$File | cut -d'.' -f1`; \
           $(MAKE) $$Base.class > /dev/null; \
        done

# build all 
build b: buildlocal buildSubDirs
	@echo "done"



# test in all subdirs
testSubDirs:
	@if [ ! -z "$(SUBDIRS)" ] ; \
        then \
	  echo "Doing tests in subdirs ..."; \
          for Dir in ""$(SUBDIRS) ; do \
            echo "------------------- in $$Dir"; \
            echo "in $$Dir" ; \
            cd $$Dir >/dev/null; \
            $(MAKE) test >/dev/null; \
            cd ..; \
            echo "------------------- (done)"; \
          done; \
          echo "done"; \
        fi

# test all
test t: build testSubDirs
	@if [ ! -z "$(TESTS)" ] ; \
        then \
	  (echo "  Self-tests in progress..."; \
          for Test in ""$(TESTS) ; do \
            echo "  ------------------- $$Test..."; \
            $$Test; \
            echo "  ------------------- (done)"; \
          done; \
          echo "done") 1>&2;\
        fi


# clean all subdirs
cleanSubDirs:
	@if [ ! -z "$(SUBDIRS)" ] ; \
        then \
	  echo "Cleaning in subdirs ..."; \
          for Dir in ""$(SUBDIRS) ; do \
            echo "------------------- in $$Dir"; \
            cd $$Dir >/dev/null; \
            $(MAKE) clean >/dev/null; \
            cd ..; \
            echo "------------------- (done)"; \
          done; \
          echo "done"; \
        fi

cleanlocal cl:
	@echo "Cleaning  (*.class, TAGS, *.orig...)"
#	@find . -path '*/.secu' -prune -o -name '*.class' -exec /bin/rm {} \;
	@rm -f *.class TAGS *.orig *.tmp *.err todel* *.todel *.log 2>/dev/null


# clean all
clean c: cleanlocal cleanSubDirs
	@echo "done"


# refresh tags
tags T:
	@echo "Refreshing tags..."
	@etags `find . -path './.secu' -prune -o -name '*.java' ` 2>/dev/null


# evaluates day work ;)
wc:
	@echo "Counting code lines..."
	@wc -l `find . -path '*/.secu' -prune -o -name '*.java'` 2>/dev/null | tail -1

indent i:
	@jindent `find . -path '*/.secu' -prune -o -name '*.java'` 2>/dev/null 

fixme f:
	@grep FIXME `find . -path '*/.secu' -prune -o -name '*.java'` 2>/dev/null ;/bin/true
	@grep TODO `find . -path '*/.secu' -prune -o -name '*.java'` 2>/dev/null ;/bin/true
	@grep "??" `find . -path '*/.secu' -prune -o -name '*.java'` 2>/dev/null ;/bin/true

