// A demo/test programm for OpenMath tree specific interfaces/classes

import java.io.*;
import java.math.BigInteger;
import fr.inria.openmath.omapi.*;
import fr.inria.openmath.omapi.implementation.*;


/* This test builds a tree using the NodeImpl class.
 * Then it serialize the tree using a TreePrinter.
 * This is very basic but should be enriched to demonstrate
 * more complex tree manipulations.
 */
public class Generator {

    Symbol s = new Symbol("+", "basic");

    // builds an unrolled fibonacci tree 
    private Node appGenerator(int depth) throws OMException {
        NodeImpl n;

        if (depth > 1) {
            n = new NodeImpl(Node.OM_APP);
            n.appendChild(new SymbolNodeImpl(s));
            n.appendChild(appGenerator(depth - 1));
            n.appendChild(appGenerator(depth - 2));
            return n;
        } else {
            return new BigIntegerNodeImpl(new BigInteger("1"));
        }

    }

    // builds a tree of OpenMath objects
    private Node treeGenerator(String args[]) throws OMException {
        NodeImpl n;

        n = new NodeImpl(Node.OM_OBJECT);
        n.appendChild(appGenerator(16));
        return n;
    }

    public static void main(String args[]) {
        Generator generator = new Generator();
        TreePrinterImpl treePrinter;
        OutputStream out;
        Node root;

        try {
            // Output will be directed to this file.
            out = new DataOutputStream(System.out);

            // This is the TreePrinter that will serialize
            // the  generated tree.
            // Here we use an XML serializer but 
            // HumanPrinter or BinaryPrinter are also 
            // available.
            treePrinter = new TreePrinterImpl(new XMLPrinter(out));
            //treePrinter = new TreePrinterImpl(new BinaryPrinter(out));
            // build the tree
            root = generator.treeGenerator(args);

            // and print it
            treePrinter.printTree(root);
            treePrinter.endPrint();
            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

}
